[llvm-commits] [llvm] r85641 - /llvm/trunk/lib/Transforms/Scalar/InstructionCombining.cpp

Evan Cheng evan.cheng at apple.com
Fri Oct 30 18:28:06 PDT 2009


Author: evancheng
Date: Fri Oct 30 20:28:06 2009
New Revision: 85641

URL: http://llvm.org/viewvc/llvm-project?rev=85641&view=rev
Log:
Revert 85634. It's breaking consumer-typeset (and others).

Modified:
    llvm/trunk/lib/Transforms/Scalar/InstructionCombining.cpp

Modified: llvm/trunk/lib/Transforms/Scalar/InstructionCombining.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Transforms/Scalar/InstructionCombining.cpp?rev=85641&r1=85640&r2=85641&view=diff

==============================================================================
--- llvm/trunk/lib/Transforms/Scalar/InstructionCombining.cpp (original)
+++ llvm/trunk/lib/Transforms/Scalar/InstructionCombining.cpp Fri Oct 30 20:28:06 2009
@@ -10981,24 +10981,22 @@
     }
   }
 
-  // If there are multiple PHIs, sort their operands so that they all list
-  // the blocks in the same order. This will help identical PHIs be eliminated
-  // by other passes. Other passes shouldn't depend on this for correctness
-  // however.
-  PHINode *FirstPN = cast<PHINode>(PN.getParent()->begin());
-  if (&PN != FirstPN)
-    for (unsigned i = 0, e = FirstPN->getNumIncomingValues(); i != e; ++i) {
+  // Sort the PHI node operands to match the pred iterator order. This will
+  // help identical PHIs be eliminated by other passes. Other passes shouldn't
+  // depend on this for correctness however.
+  unsigned i = 0;
+  for (pred_iterator PI = pred_begin(PN.getParent()),
+       PE = pred_end(PN.getParent()); PI != PE; ++PI, ++i)
+    if (PN.getIncomingBlock(i) != *PI) {
+      unsigned j = PN.getBasicBlockIndex(*PI);
+      Value *VA = PN.getIncomingValue(i);
       BasicBlock *BBA = PN.getIncomingBlock(i);
-      BasicBlock *BBB = FirstPN->getIncomingBlock(i);
-      if (BBA != BBB) {
-        Value *VA = PN.getIncomingValue(i);
-        unsigned j = FirstPN->getBasicBlockIndex(BBA);
-        Value *VB = PN.getIncomingValue(j);
-        PN.setIncomingBlock(i, BBB);
-        PN.setIncomingValue(i, VB);
-        PN.setIncomingBlock(j, BBA);
-        PN.setIncomingValue(j, VA);
-      }
+      Value *VB = PN.getIncomingValue(j);
+      BasicBlock *BBB = PN.getIncomingBlock(j);
+      PN.setIncomingBlock(i, BBB);
+      PN.setIncomingValue(i, VB);
+      PN.setIncomingBlock(j, BBA);
+      PN.setIncomingValue(j, VA);
     }
 
   return 0;





More information about the llvm-commits mailing list